import React, { PropTypes } from 'react'
import { css } from 'glamor'
import cx from 'classnames'
import Text from './Text'
import theme from './theme'

const getStyle = ({ primary, secondary, danger }) => {
  let intent

  if (danger) intent = theme.intent.danger
  else if (secondary) intent = theme.intent.secondary
  else if (primary) intent = theme.intent.primary

  if (!intent) return ''

  return css({
    color: intent.default.linkColor,
    '&:hover': {
      color: intent.hover.linkColor
    },
    '&:focus': {
      color: intent.focus.linkColor
    },
    '&:active, &.active': {
      color: intent.active.linkColor
    }
  })
}

const baseStyles = css({
  transition: 50,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  textDecoration: 'none',
  '&.underline': {
    textDecoration: 'underline'
  },
  '&:active, &:focus': {
    outline: 'none'
  }
})

const parseProps = ({
  underline,
  active,
  primary,
  secondary,
  danger,
  naked,
  className,
  ...props
}) => ({
  className: cx(`${baseStyles}`,
    `${getStyle({ primary, secondary, naked, danger })}`,
    underline && 'underline',
    active && 'active',
    className),
  is: active ? 'span' : 'a',
  ...props
})

const Link = props => React.createElement(Text, parseProps(props))

Link.propTypes = {
  ...Text.propTypes,
  underline: PropTypes.bool,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  active: PropTypes.bool
}

Link.defaultProps = {
  // underline: true,
  primary: true
}

Link.displayName = 'Link'

export default Link
